/***********************************************************************************************************************
 *
 * blueBill Mobile - Android - open source birding
 * Copyright (C) 2009-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://bluebill.tidalwave.it/mobile
 * SCM: https://java.net/hg/bluebill-mobile~android-src
 *
 **********************************************************************************************************************/
package it.tidalwave.bluebill.taxonomy.mobile.impl;

import javax.annotation.Nonnull;
import javax.annotation.concurrent.Immutable;
import java.util.HashMap;
import java.util.Locale;
import java.util.Map;
import it.tidalwave.util.Id;
import it.tidalwave.util.NotFoundException;
import it.tidalwave.bluebill.taxonomy.mobile.Taxon;

/***********************************************************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
@Immutable
public class LocalizedNamesBag
  {
    @Nonnull
    private final Locale locale;

    private final Map<Id, String> map = new HashMap<Id, String>();

    public LocalizedNamesBag (final @Nonnull Locale locale, 
                              final @Nonnull Map<Id, String> map)
      {
        this.locale = locale;
        this.map.putAll(map);
      }

    @Nonnull
    public String getLocalizedName (final @Nonnull Taxon taxon)
      throws NotFoundException
      {
        // FIXME: string concatenation here kills the performance - make it "No name for %s", taxon);
//        return NotFoundException.throwWhenNull(map.get(taxon.getId()), "No name for " + taxon);
        return NotFoundException.throwWhenNull(map.get(taxon.getId()), "No name for taxon");
      }

    @Nonnull
    public Locale getLocale()
      {
        return locale;
      }

    @Override @Nonnull
    public String toString()
      {
        return String.format("LocalizedNamesBag[%s]", locale);
      }
  }
